==> kubernetes-model-core-5.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecretKeySelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SecretKeySelectorBuilder extends SecretKeySelectorFluentImpl<SecretKeySelectorBuilder> implements VisitableBuilder<SecretKeySelector,SecretKeySelectorBuilder> {

    SecretKeySelectorFluent<?> fluent;
    Boolean validationEnabled;

    public SecretKeySelectorBuilder() {
        this(true);
    }

    public SecretKeySelectorBuilder(Boolean validationEnabled) {
        this(new SecretKeySelector(), validationEnabled);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent) {
        this(fluent, true);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SecretKeySelector(), validationEnabled);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,SecretKeySelector instance) {
        this(fluent, instance, true);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,SecretKeySelector instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withKey(instance.getKey()); 
        fluent.withName(instance.getName()); 
        fluent.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public SecretKeySelectorBuilder(SecretKeySelector instance) {
        this(instance,true);
    }

    public SecretKeySelectorBuilder(SecretKeySelector instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withKey(instance.getKey()); 
        this.withName(instance.getName()); 
        this.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public SecretKeySelector build() {
        SecretKeySelector buildable = new SecretKeySelector(fluent.getKey(),fluent.getName(),fluent.isOptional());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SecretKeySelectorBuilder that = (SecretKeySelectorBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecretKeySelectorBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SecretKeySelectorBuilder extends SecretKeySelectorFluentImpl<SecretKeySelectorBuilder> implements VisitableBuilder<SecretKeySelector,SecretKeySelectorBuilder> {

    SecretKeySelectorFluent<?> fluent;
    Boolean validationEnabled;

    public SecretKeySelectorBuilder() {
        this(true);
    }

    public SecretKeySelectorBuilder(Boolean validationEnabled) {
        this(new SecretKeySelector(), validationEnabled);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent) {
        this(fluent, true);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SecretKeySelector(), validationEnabled);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,SecretKeySelector instance) {
        this(fluent, instance, true);
    }

    public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,SecretKeySelector instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withKey(instance.getKey()); 
        fluent.withName(instance.getName()); 
        fluent.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public SecretKeySelectorBuilder(SecretKeySelector instance) {
        this(instance,true);
    }

    public SecretKeySelectorBuilder(SecretKeySelector instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withKey(instance.getKey()); 
        this.withName(instance.getName()); 
        this.withOptional(instance.getOptional()); 
        this.validationEnabled = validationEnabled; 
    }

    public SecretKeySelector build() {
        SecretKeySelector buildable = new SecretKeySelector(fluent.getKey(),fluent.getName(),fluent.getOptional());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SecretKeySelectorBuilder that = (SecretKeySelectorBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
